---
title: "AI for healthcare"
author: "Jean Feydy"
institute: ""
topic: ""
theme: "metropolis"
colortheme:
fonttheme:
fontsize: 11pt
linkcolor: black
urlcolor: blue
linkstyle: bold
aspectratio: 169
titlegraphic: 
logo:
date:
section-titles: false
toc: false
---


## Recap of the previous lecture

Lecture 3 -- **Graphs**:

- **Curse of dimensionality** $~~\Longrightarrow~~$ Statistics on `\BR{white noise}`{=latex} is hopeless.

- We must understand the **intrinsic** structure of our data, \
  even when it is **embedded** in a high-dimensional space of features.

- We may need to **unwrap** the manifold of plausible data samples.


## Graphs = local neighborhood structures


::: columns
:::: {.column width=45%}
`\begin{center}\vspace*{.5cm}`{=latex}

![](images/knn_graph.png){ height=4cm }

 \
The K-NN graph describes \
the **local** structure of a dataset.

`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}\vspace*{.5cm}`{=latex}

![](images/spaghetti.jpg){ height=4cm }

 \
Untangling a soup of edges to produce \
a **global** understanding is hard.

`\end{center}`{=latex}
::::
:::






## Simple archetypes `\cite{topping2021understanding}`{=latex}

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/dimension/clique.png){height=4cm}

 \
**Cliques** are like balls \
with positive curvature.

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/dimension/grid.png){height=4cm}

 \
**Grids** are like planes \
with flat curvature.

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/dimension/tree.png){height=4cm}

 \
**Trees** are like saddles \
with negative curvature.

`\end{center}`{=latex}
::::
:::





## Simple archetypes

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/curvature/5_triangles.jpg){height=4cm}

 \
**Cliques** are like balls \
with positive curvature.

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/curvature/6_triangles.jpg){height=4cm}

 \
**Grids** are like planes \
with flat curvature.

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/curvature/7_triangles.jpg){height=4cm}

 \
**Trees** are like saddles \
with negative curvature.

`\end{center}`{=latex}
::::
:::


## Embedding methods such as UMAP are excellent diagnostic tools `\cite{umapprime}`{=latex}

::: columns
:::: {.column width=45%}
`\begin{center}\vspace*{.25cm}`{=latex}

![](images/umap/primes_umap_8e6.png){ height=5cm }

 \
Visualizing the set of **integer numbers** \
1, 2, 3, ..., 8,000,000.

`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}\vspace*{.25cm}`{=latex}

![](images/umap/HSC.png){ height=5cm }

 \
Visualizing the differentiation of \
Hematopoietic **stem cells**.

`\end{center}`{=latex}
::::
:::




## Since 2012, we have grown used to convolutional neural networks `\cite{hollandais}`{=latex}

`\begin{center}`{=latex}

![](images/CNN_archi.png){height=95%}

`\end{center}`{=latex}



## Can we apply this methodology to higher-level descriptions? `\cite{heart_raw, heart_pop}`{=latex}

```{=latex}
\vspace{-.43cm}
\begin{align*}
	\text{1. Pixels} &&
  \text{2. Anatomy} &&
	\text{3. Function}
\end{align*}

\begin{figure}
	\centering %
		\includegraphics[height=.55\textheight]{images/voisinages/heart_models.png}
		\begin{center}
		Simplifying a bit, each level of analysis corresponds to\\
		a way of \textbf{grouping pixels} with their neighbors.
		\end{center}
\end{figure}
```




## Today's lecture -- an active research topic

**1. Geometric deep learning is *not* a mature field:**

  - Convolutions on graphs and point clouds.
  - A stimulating environment.
  - Questionable benchmarks.

**2. Personal experience feedback:**

  - Protein docking.
  - Lung registration.

**3. Trying to learn a graph structure:**

  - Dynamic graphs, auto-encoders and transformers.
  - A continuous spectrum of models and jobs.


# Geometric deep learning `\\`{=latex} is *not* a mature field



## What is a convolution?

```{=latex}
\textbf{Convolution} (i.e. weighted average of the neighboring pixels)~:\\
\hspace*{10mm} Cheap generalization of the \textbf{product} ``$\text{a}\cdot \xc{\text{x}}$'',\\
\hspace*{10mm} parameterized by the coefficients of a \textbf{small filter} $\varphi$.

\vspace{1cm}
\begin{center}
\begin{tabular}{ccccc}
	\begin{minipage}{1cm}
	\only<1>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_1.png} }
	\only<2>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_2.png} }
	\only<3>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_3.png} }
	\only<4>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_4.png} }
	\only<5>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_5.png} }
	\only<6>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_6.png} }
	\only<7>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_7.png} }
	\only<8>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filter_8.png} }
	\end{minipage}
	& 
	\begin{minipage}{1cm} \vspace{-.5cm} {\huge $~\star$ } \end{minipage}
	&
	\begin{minipage}{3cm}
	\only<1>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<2>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<3>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<4>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<5>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<6>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<7>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<8>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\end{minipage}
	& 
	\begin{minipage}{1cm} \vspace{.1cm} {\huge $~~=~~$ } \end{minipage}
		&
	\begin{minipage}{3cm}
	\only<1>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_1.png} }
	\only<2>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_2.png} }
	\only<3>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_3.png} }
	\only<4>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_4.png} }
	\only<5>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_5.png} }
	\only<6>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_6.png} }
	\only<7>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_7.png} }
	\only<8>{ \includegraphics[width=\linewidth,height=\linewidth]{images/convolution/filtered_8.png} }
	\end{minipage} \\
	$\varphi$ && $\xc{\text{x}}$ && \only<1-5>{$\varphi \star \xc{x}$}\only<6->{$|\varphi \star \xc{\text{x}}|$}
\end{tabular}
\end{center}
```

## What is a convolution?

Convolutions on **grids**:

  - Are **cheap**.

  - Enable **pattern** detection and **texture** analysis.

  - `\BR{Proven track record}`{=latex} since the 1960's: \
    Gaussian blur, edge detectors, Laplacian pyramids, \
    wavelets, JPEG2000, convolutional neural networks...


## Message-passing on graphs `\cite{dwivedi2020benchmarking}`{=latex}

::: columns
:::: {.column width=45%}
`\begin{center}\vspace*{.25cm}`{=latex}

![](images/mnist/mnist_grid_conv.png){ height=5cm }

 \
$\text{x}\,[\,\text{i}, \text{j}\,] ~\gets~ \sum_{\text{k},\text{l}} \textcolor{green!60!black}{\varphi\,[\,\text{k}, \text{l}\,]}\,\cdot\, \text{x}\,[\,\text{i}-\text{k}, \text{j}-\text{l}\,]$

`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}\vspace*{.25cm}`{=latex}

![](images/mnist/mnist_graph_conv.png){ height=5cm }

 \
$\text{x}\,[\,\text{i}\,]\, \gets \sum_{\text{i} \leftrightarrow\text{k}} \textcolor{green!60!black}{\varphi \big(} \text{x}\,[\,\text{i}\,],  \text{x}[\,\text{k}\,],  \textcolor{green!60!black}{\text{edge}\,[\,\text{i},\text{k}\,]\, \big)}$

`\end{center}`{=latex}
::::
:::



## Multiscale architectures on graphs `\cite{mallatcnn,bronstein2021geometric}`{=latex}

::: columns
:::: {.column width=55%}
`\begin{center}\vspace*{.25cm}`{=latex}

![](images/pooling/wavelet.png){ height=5cm }

 \
**Grid** convolutions \
+ downsamplings.

`\end{center}`{=latex}
::::
:::: {.column width=40%}
`\begin{center}\vspace*{.25cm}`{=latex}

![](images/pooling/graph_nn.png){ height=5cm }

 \
**Graph** convolutions \
+ downsamplings.
`\end{center}`{=latex}
::::
:::


## The promises of geometric deep learning

We intend to leverage the `\BR{intrinsic structure}`{=latex} of:

- **Point** clouds.
- Surface and volume **meshes**.
- **Molecular** graphs, proteins.
- Social and communication **networks**.

`\begin{center}\vspace*{1cm}`{=latex}
Unfortunately, things are **not that simple**.
`\end{center}`{=latex}




## Problem 1: How do we deal with the lack of orientation? `\cite{cammarata2020curve,hairy_ball}`{=latex}

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/orientation/curve_detector.png){height=4cm}

 \
CNNs learn **oriented** \
curve detectors.

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/orientation/radial_filter.pdf){height=4cm}

 \
Vanilla graph convolutions \
define `\BR{isotropic}`{=latex} filters.

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/orientation/Baby_hairy_head_DSCN2483.jpeg){height=4cm}

 \
**Hairy ball theorem**: no globally
consistent 2D coordinates on a sphere.

`\end{center}`{=latex}
::::
:::



## Problem 2: How do we deal with varying sampling densities? `\cite{sharp2019navigating}`{=latex}

`\vspace*{.8cm}`{=latex}

::: columns
:::: {.column width=25%}
`\begin{center}\vspace*{.17cm}`{=latex}
![](images/Cardiac_mri_slice_bionerd.jpg){height=2.8cm}

 \
MRI slice: \
**voxel size** = 1 $\text{mm}^\text{3}$.

`\end{center}`{=latex}
::::
:::: {.column width=35%}
`\begin{center}`{=latex}
![](images/sampling/hell_is_other_people_s_meshes.png){height=2.8cm}

 \
"**Hell** is other people's meshes" \
-- Jean-Paul Sartre

`\end{center}`{=latex}
::::
:::: {.column width=35%}
`\begin{center}`{=latex}
![](images/sampling/intrinsic.png){height=2.8cm}

 \
**Intrinsic** triangulations. \
Can we use them for ML?

`\end{center}`{=latex}
::::
:::



## Problem 3: How do we deal with highly non-Euclidean graphs? `\cite{topping2021understanding}`{=latex}

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=35%}
`\begin{center}`{=latex}
![](images/pooling/downsampling.png){height=4cm}

 \
Downsampling a **grid** is easy.

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/pooling/clique.png){height=4cm}

 \
How do we downsample \
a **clique**?

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/pooling/bottleneck.png){height=4cm}

 \
How do we handle **bottlenecks**?

`\end{center}`{=latex}
::::
:::



## Problem 4: GPUs are not optimized for graphs

`\vspace*{1cm}`{=latex}

::: columns
:::: {.column width=40%}
`\begin{center}`{=latex}
![](images/GPU/convolution_grid.pdf){height=4cm}

 \
**Fixed** + **contiguous** neighborhoods \
$\Longrightarrow~$ Optimal compilation.
`\end{center}`{=latex}
::::
:::: {.column width=55%}
`\begin{center}`{=latex}
![](images/GPU/convolution_graph.pdf){height=4cm}

 \
**Varying** sizes + **random** memory accesses \
$\Longrightarrow~$ x100 slow-down.

`\end{center}`{=latex}
::::
:::




## Problem 5: The range of target applications is too wide. `\cite{molecules,lidar,social_network}`{=latex}

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/applications/molecules.jpeg){height=3cm}

 \
Molecules.

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/applications/lidar.png){height=3cm}

 \
Lidar scans.

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/applications/Social_Network_Analysis_Visualization.png){height=3cm}

 \
Social networks.

`\end{center}`{=latex}
::::
:::


## A fast-growing community

In 2017, geometric deep learning was `\BR{a solution in search of a problem}`{=latex}.

With an appealing pitch, it attracted:

- **Computer scientists**, looking for new ways of combining features.

- **Mathematicians**, looking for new applications of their insights.

- **Domain experts**, looking for a breakthrough on their data.


## A blooming corpus of methods

The literature since 2017:

- Dozens of different **convolution** operators.

- Renewed interest in **theoretical graph ML**.

- Useful **extensions** for PyTorch: PyG, DGL, KeOps...

- `\BR{Cross-pollination}`{=latex} between different fields: \
  computer graphics, signal processing, chemistry...


## A field without consensus

Unfortunately, it is hard to recommend some methods over the others:

- Applications are **wildly different** from each other.

- Most theoretical and experimental works are **proof-of-concepts**.

- Benchmarks are `\BR{highly unreliable}`{=latex}.


## We like to think that science is done in a vacuum

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/archimedes.jpeg){height=5cm}

 \
Archimedes -- "Don't disturb my circles".
`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/Albert_Edelfelt_-_Louis_Pasteur_-_1885.jpg){height=5cm}

 \
Louis Pasteur, alone in the lab.

`\end{center}`{=latex}
::::
:::


## Scientific literatures are shaped by structural incentives


**French mathematicians** -- top 3 deepest ideas over a career:

- Promotes `\BR{long-term}`{=latex}, original thought.
- No incentives for outreach and interdisciplinary research.

**INRIA researchers** -- 1 meaningful contribution every 5 years:

- A theorem, a piece of software, a patent, a societal breakthrough...
- Outstanding place for **applied** research.

**French medical doctors/teachers/researchers** -- PubMed index:

- MERRI funds compensate hospitals for research activities.
- Fall behind the profitability threshold $\Longrightarrow$ shut down the lab, focus on care.
- `\BR{Inflation}`{=latex} of low-quality papers.


## Structural incentives in US/UK CS teams

**Universities** -- climb up the Shanghai ranking:

- 1 (foreign) student = \$30k-\$70k per year.
- Maximize the **number** of papers to impress prospective students.


**Professors** -- maximize the hype:

- Unstable "tenure track" contract, commited to a grant, startup to grow...
- Allowed to take risks, but `\BR{not allowed to fail}`{=latex}.


**Students** -- target a job in the tech companies:

- Significant debt to pay back.
- Safest route: **incremental** research, claim SOTA every 6 months.


## Peer-reviewed $~~\neq~~$ Scientific truth

In the current ML community, relatively `\BR{few actors are incentivized}`{=latex} to:

- Review papers carefully.
- Document **baselines** thoroughly.
- Admit that an idea **doesn't work**.
- Take the **massive** amount of time that is needed \
  to make their experiments **truly** reproducible.
- Keep the codebase up to date with a software stack that breaks every 6 months.

`\begin{center}`{=latex}

$\Longrightarrow$ Unfortunately, the NeurIPS/ICML/... stamp means little. \
We cannot **trust** the conclusions of a paper \
without **reproducing** the experiments \
or **checking** the proofs carefully.

`\end{center}`{=latex}



## Some common benchmarks are nothing but sanity checks `\cite{mnist,dwivedi2020benchmarking}`{=latex}

`\vspace*{.5cm}`{=latex}

`\begin{center}`{=latex}
![](images/mnist/mnist.png){height=5cm}

Results on **Graph-MNIST** look promising... Until you remember that \
test accuracy for **basic K-NN classifiers** on MNIST is 95\%-99\%.
`\end{center}`{=latex}




## Some common benchmarks have been saturated for years `\cite{rozenberszki2022language}`{=latex}

`\vspace*{.5cm}`{=latex}

`\begin{center}`{=latex}
![](images/scannet_200.jpg){width=95%}

 \
**Challenging** large-scale benchmarks are published every year... \
But the review system pushes authors towards **overfitting on "classic" datasets**.
`\end{center}`{=latex}



## Some benchmarks have been taken out of context `\cite{faust_dataset}`{=latex}

`\begin{center}`{=latex}
![](images/faust/faust_real.png){height=5cm}

The MPI FAUST dataset contains 300 real-life scans of 10 subjects -- 30 poses each.\
**Problem:** fit a reference mesh to the **noisy 3D point clouds**.\
`\BR{Challenges:}`{=latex} different topologies, missing data, self contacts. \
Dense ground truth correspondence for training = 10x10 meshes with identical topology.
`\end{center}`{=latex}


## Some benchmarks have been taken out of context `\cite{faust_dataset}`{=latex}


`\begin{center}`{=latex}
![](images/faust/faust_meshes.jpg){height=5cm}

The PyG library and many papers on graph neural networks \
`\BR{discard the original point clouds}`{=latex} to focus entirely on the 100 pre-aligned meshes. \

**New problem:** use $(\text{x},\text{y},\text{z})$ coordinates as input features for each node \
$\Longrightarrow$ predict node indices in $[\text{1}, \text{6890}]$ as output signal. \
Train on 80 surfaces, test on the remaining 20. \
\
`\BR{Irrelevant}`{=latex} **to shape registration**: we learn to `\BR{overfit on the reference triangulation}`{=latex}.

`\end{center}`{=latex}


## How can we judge?


`\begin{center}`{=latex}
Keep track of both **classical** and **learning-based** \
baselines, in each application domain.

This is time-consuming -- `\BR{focus on 2-3 subjects at most.}`{=latex} \
\
\
It is likely that the wave of papers on geometric deep learning \
will **fade** in most applications settings, \
and **stick** in some productive niches: \
Shape analysis? Chemistry? Social sciences?

This is how scientific progress takes place. \
The hype cycle is a **normal** and well-documented phenomenon.
`\end{center}`{=latex}


# Some personal experience


## Two problems in structural biology `\cite{dmasif}`{=latex}

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=55%}
`\begin{center}`{=latex}
![](images/proteins/folding.jpg){height=4cm}

 \
**Folding** and design.
`\end{center}`{=latex}
::::
:::: {.column width=40%}
`\begin{center}`{=latex}
![](images/proteins/docking.png){height=4cm}

 \
**Docking** -- interacting surfaces.

`\end{center}`{=latex}
::::
:::


## Docking is a function of the protein surfaces `\cite{gainza2020deciphering}`{=latex}

`\begin{center}\vspace*{.5cm}`{=latex}
![](images/proteins/masif_1.png){height=4cm}

 \
**Physical prior**: no need to deal with the full volumes, \
we are looking for `\BR{surface fingerprints}`{=latex}.

`\end{center}`{=latex}



## Docking is a function of the protein surfaces `\cite{gainza2020deciphering}`{=latex}

`\begin{center}\vspace*{.8cm}`{=latex}
![](images/proteins/masif_2.png){height=4cm}

 \
We can compute **geometric** and **chemical** `\BR{input features}`{=latex} \
on local patches with $\simeq\text{1\,nm}$ radius.

`\end{center}`{=latex}


## Docking is a function of the protein surfaces `\cite{gainza2020deciphering}`{=latex}

`\begin{center}\vspace*{.2cm}`{=latex}
![](images/proteins/masif_3.png){height=5cm}

And perform all classification tasks on **geodesic patches**. \
Built-in **invariance** to 3D rotations, translations and the inner content of the protein. \
Enforces a **locality** prior: won't overfit on scattered patterns.

`\end{center}`{=latex}



## Docking is a function of the protein surfaces `\cite{gainza2020deciphering}`{=latex}

`\begin{center}\vspace*{.8cm}`{=latex}
![](images/proteins/masif_4.png){height=4cm}

 \
After training on the Protein Data Bank (with **careful** train-test split), \
this enables three tasks of interest.

`\end{center}`{=latex}


## A proof-of-concept that has been received well `\cite{gainza2020deciphering,dmasif,sverrisson2022physics}`{=latex}


```{=latex}
	\vspace*{.5cm}
	\begin{center}
		%\includegraphics[width=.75\linewidth]{images/proteins/overview.pdf}
		{\scriptsize
			\def\svgwidth{.75\linewidth}\vspace{-2mm}
			\import{images/proteins/}{overview.pdf_tex}
		}
	\end{center}
    \vspace{.5cm}
    
	\centerline{
	\begin{tabular}{ccc}
		\begin{minipage}{2.5cm}
			\includegraphics[width=\linewidth]{images/proteins/nature_cover.png}
		\end{minipage}
		&{\huge $\longrightarrow$}
		&
		\begin{minipage}{5cm}
			$\times$100\,-$\times$1,000 faster, lighter\\
			\phantom{.}~~~~~and fully differentiable.
		\end{minipage}
	\end{tabular}
	}
```



## Is deep learning truly a revolution? `\cite{alford2017rosetta}`{=latex}

`\begin{center}\vspace*{.2cm}`{=latex}
![](images/proteins/rosetta.png){height=5cm}


After 20 years of work, the developers of the Rosetta software have \
*de facto* developed a `\BR{hybrid ``point neural network''}`{=latex} that combines \
**physical** potentials with **data-driven** residuals.

`\end{center}`{=latex}


## Recap on the MaSIF-dMaSIF project

Personal feedback:

- Inspiring `\BR{prototype}`{=latex} that shows how far we can go if we \
  **drop** complex physical terms but **preserve** the symmetries of the problem.

- With clever geometry and code, we can do interesting science on a **single GPU**.

- Nowhere near close to a finished product: **maintaining** software is a full-time job.

- **Well-funded** and **mature** fields already showcase formidable baselines. \
  As outsiders, we can propose **stimulating** ideas and tools. \
  Always `\BR{stay humble}`{=latex} -- understanding the full context takes years. 



## Lung registration "Exhale -- Inhale" `\cite{shen2021accurate}`{=latex}

`\begin{center}`{=latex}

![](images/robot/poumons.png){height=80%}

`\vspace*{-.3cm}`{=latex}

**Complex** deformations, high **resolution** (50k--300k points), high **accuracy** ($<$ 1mm). \
`\BR{Point clouds}`{=latex} are more challenging than volumes, but **robust** to acquisition parameters. 

`\end{center}`{=latex}

## Point neural networks `\cite{wu2020pointpwc,shen2021accurate}`{=latex}

::: columns

:::: {.column width=50%}

`\begin{center}`{=latex}
`\vspace*{.65cm}`{=latex}

![](images/robot/deep_reg_module.pdf){height=4cm}

`\vspace*{.5cm}`{=latex}
**Multi-scale** convolutional \
point neural network.

`\end{center}`{=latex}


::::

:::: {.column width=50%}

`\begin{center}`{=latex}
`\vspace*{.6cm}`{=latex}

![](images/robot/PointPWC.pdf){height=4cm}

`\vspace*{.25cm}`{=latex}
Architecture of a \
PointPWC **block**.

`\end{center}`{=latex}

::::


:::




## Point neural networks -- strengths and limitations `\cite{shen2021accurate}`{=latex}

::: columns

:::: {.column width=50%}

`\begin{center}`{=latex}
`\vspace*{.85cm}`{=latex}

![](images/robot/deep_reg_module.pdf){height=4cm}

`\vspace*{.5cm}`{=latex}
**Multi-scale** convolutional \
point neural network.

`\end{center}`{=latex}


::::

:::: {.column width=50%}

`\vspace*{.6cm}`{=latex}
Point neural nets, **in practice**:

- Compute **descriptors** at all scales.
- **Match** them using geometric layers.
- Train on **synthetic** deformations.

\
Strengths and weaknesses:

- Good at **pairing** branches.
- Hard to train to high **accuracy**.

`\begin{center}\vspace*{.5cm}`{=latex}
$\Longrightarrow$ **Complementary** to geometric methods \
such as optimal transport.
`\end{center}`{=latex}

::::


:::




## Three-steps registration `\cite{shen2021accurate}`{=latex}

`\begin{center}\vspace*{.2cm}`{=latex}

![](images/robot/drobot_summary.pdf){width=100%}

`\end{center}\vspace*{-.5cm}`{=latex}

 \
This **pragmatic** method:

- Is **easy to train** on synthetic data.
- Scales up to high-resolution: 100k points in 1s.
- Excellent results: **KITTI** (outdoors scans) and **DirLab** (lungs).


## Three-steps registration


`\begin{center}`{=latex}

![](images/robot/full.png){height=85%}

`\end{center}\vspace*{-.3cm}`{=latex}


## Evaluation on the 3D Kitti dataset `\cite{menze2015object,menze2015joint,sejourne2019sinkhorn}`{=latex}


`\begin{center}\vspace*{.5cm}`{=latex}

![](images/robot/kitti.png){height=85%}

**3D scene flow** estimation task, derived from a **2D + depth** dataset. \
This is a standard (but maybe questionable) benchmark.

`\end{center}\vspace*{-.3cm}`{=latex}



## Evaluation on the 3D Kitti dataset `\cite{shen2021accurate}`{=latex}


`\begin{center}`{=latex}

![](images/robot/kitti_results.png){height=85%}

`\BR{Surprise:}`{=latex} a **baseline** optimal transport solver with smoothing (RobOT) \
outperforms many **deep learning** methods on all metrics.

`\end{center}\vspace*{-.3cm}`{=latex}




## Recap on the registration project `\cite{castillo2013reference}`{=latex}

Personal feedback:

- Pragmatic approach: get the `\BR{best of both}`{=latex} **data-driven** and **deterministic** methods.

- **Tables** of numbers look impressive -- but can **hide** critical information.

- **Code** base is not clean -- top priority going forward.

- Evaluation on 3D scene flow is **questionable**. \
  Shouldn't we work with the original 2D data?

- Evaluation on **medical data** is hard:

  - We release a new dataset of **1,000 pairs for training** -- without annotations.
  - We only have access to **10 pairs** with dense annotations **for evaluation**.



# Should we learn our graphs?


## Dynamic graph CNNs  `\cite{wang2019dynamic}`{=latex}

`\begin{center}\vspace*{.5cm}`{=latex}

![](images/graph_learning/dgcnn.png){height=65%}

At every layer, use the **K-NN graph** of the `\BR{feature vectors}`{=latex}. \
This may promote **semantic** neighborhoods.

`\end{center}\vspace*{-.3cm}`{=latex}



## Embeddings and autoencoders `\cite{autoencoders}`{=latex}

`\begin{center}\vspace*{.5cm}`{=latex}

![](images/graph_learning/autoencoder_schema.jpg){height=85%}

Use the **K-NN graph** of a `\BR{low-dimensional}`{=latex} representation: \
UMAP, an encoder-decoder architecture...

`\end{center}\vspace*{-.3cm}`{=latex}


## Attention layers and transformers `\cite{cheng2016long,vaswani2017attention}`{=latex}

`\begin{center}\vspace*{.25cm}`{=latex}

![](images/graph_learning/attention_1.pdf){height=65%}

We would like to define convolutional architectures on **sentences**. \
But the **1D structure** of the text is not always relevant. \
 \

`\end{center}\vspace*{-.3cm}`{=latex}


## Attention layers and transformers `\cite{cheng2016long,vaswani2017attention}`{=latex}

`\begin{center}\vspace*{.25cm}`{=latex}

![](images/graph_learning/attention_2.pdf){height=65%}

Instead, we **embed feature vectors** in a semantic space. \
`\BR{Attention}`{=latex} $~=~$ data-driven embedding + convolution. \
`\BR{Transformer}`{=latex} $~=~$ stack of attention layers. \


`\end{center}\vspace*{-.3cm}`{=latex}


## Attention layers and transformers `\cite{cheng2016long,vaswani2017attention}`{=latex}

::: columns
:::: {.column width=50%}

 \
`\BR{Cheap and expressive}`{=latex} convolution on the feature vectors $\text{x}_\text{i}$:

- Query vectors $~~\,\text{q}_\text{i} \gets \text{MLP}_\text{q}(\text{x}_\text{i})$.
- Key $~~~~~$ vectors $~~\text{k}_\text{i} \gets \text{MLP}_\text{k}(\text{x}_\text{i})$.
- Value $~$ vectors $~~\,\text{v}_\text{i} \gets \text{MLP}_\text{v}(\text{x}_\text{i})$.

- **Nadaraya--Watson interpolation** with a kernel $\text{k}(\text{x},\text{y}) = \exp(\text{x}\cdot\text{y})$:

  $$\text{x}_\text{i} ~~\gets~~ \frac{\sum_\text{j} \exp( \text{q}_\text{i} \cdot \text{k}_\text{j}) \, \text{v}_\text{j}}{\sum_\text{j} \exp( \text{q}_\text{i} \cdot \text{k}_\text{j}) }$$

`\begin{center}\vspace*{.25cm}`{=latex}
This architecture trains remarkably well \
on **web-scale** corpuses. 
`\end{center}`{=latex}
::::
:::: {.column width=50%}
`\begin{center}`{=latex}![](images/graph_learning/attention_2D.png){height=8cm}`\end{center}`{=latex}
::::
:::


## Problem 1: In most important settings, data is expensive and fragmented `\cite{amazon_turk}`{=latex}


::: columns
:::: {.column width=60%}


 \
The Web and the Amazon Mechanical Turk \
are `\BR{the exceptions}`{=latex}, not the rule:

- **1** protein structure in 3D \
  $~=~$ **months** of work for a biologist.

- **50** fully documented patients \
  $~=~$ a great **thesis** for a radiologist.

- **1** patient in a clinical trial \
  $~\simeq~$ **\$40k**, up to \$1M for surgery! \
  \

- Getting **legal** access to large datasets *and* computers 
  is extremely difficult in any field \
  that has a signficant **societal impact**.


::::
:::: {.column width=40%}
`\begin{center}\vspace*{.25cm}`{=latex}![](images/lemonde_mechanical_turk.jpg){height=6cm}`\end{center}`{=latex}
::::
:::


## Problem 2: Bigger models are slower, heavier and cumbersome `\cite{chemical_plant}`{=latex}


::: columns
:::: {.column width=60%}

 \
 \
We must `\BR{strike a balance}`{=latex} between:

- Speed.

- Accuracy.

- **Hardware** and **development** costs.

- **Energy** consumption $~=~$ battery life.

- **Interpretability** $~=~$ easy to debug \
  `\phantom{\textbf{Interpretability}}`{=latex} $~=~$ easy to `\BR{maintain}`{=latex}.


`\begin{center}\vspace*{.25cm}`{=latex}
Tons of equations $~~\simeq~~$ Tons of parameters. \
Only worth the **trouble** if there is no other option.

`\end{center}`{=latex}

::::
:::: {.column width=40%}
`\begin{center}\vspace*{.25cm}`{=latex}![](images/chemical_plant.jpeg){height=6cm}`\end{center}`{=latex}
::::
:::

## Problem 3: In mature fields, structure is key to generalize

`\begin{center}\vspace*{.25cm}`{=latex}

![](images/gravity.png){height=65%}

This is especially true in fields that are close to physics, robotics... \
Fitting piecewise **linear** functions to **parabolas** or **exponentials** \
is fine for **interpolation**, but very limiting for `\BR{extrapolation}`{=latex}.

`\end{center}\vspace*{-.3cm}`{=latex}



## A continuous spectrum of scientific fields

`\begin{center}\vspace*{.25cm}`{=latex}

![](images/conclusion/spectrum.pdf){height=70%}

"The **unreasonable effectiveness** of mathematics in the natural sciences" \
and "the **bitter lesson** of AI" apply to `\BR{different ends}`{=latex} of this spectrum. 

`\end{center}\vspace*{-.3cm}`{=latex}



## Monopolies claim that "bigger is better"

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=33%}
`\begin{center}`{=latex}
![](images/conclusion/bike.jpg){height=3.5cm}

Electric bikes travel \
at **30 km/h**.

`\end{center}`{=latex}
::::
:::: {.column width=33%}
`\begin{center}`{=latex}
![](images/conclusion/jet.jpg){height=3.5cm}

Private jets travel \
at **800 km/h**.

`\end{center}`{=latex}
::::
:::: {.column width=25%}
`\begin{center}`{=latex}
![](images/conclusion/falcon_heavy.jpg){height=3.5cm}

Rockets travel \
at **30,000 km/h**.

`\end{center}`{=latex}
::::
:::

`\begin{center}`{=latex}

\
\
Raw performance metrics `\BR{do not tell the whole story.}`{=latex}
`\end{center}`{=latex}



## Choose your own path 

`\begin{center}\vspace*{.5cm}`{=latex}

![](images/conclusion/insects.pdf){height=65%}

`\end{center}`{=latex}


## Tech companies target your "fear of missing out"

::: columns
:::: {.column width=50%}


`\begin{center}\vspace*{1.5cm}`{=latex}

"We should **stop** training radiologists **now**. \
\
It's just **completely obvious** that within **five years**,
deep learning is going to do **better** than radiologists." \
\
-- Geoffrey Hinton, Google Brain and UToronto, `\BR{in 2016}`{=latex}.

`\end{center}`{=latex}
::::
:::: {.column width=50%}
`\begin{center}`{=latex}![](images/conclusion/geoffrey_hinton.jpg){height=7cm}`\end{center}`{=latex}
::::
:::


## Tech companies want you to forget that targeting ads $\neq$ solving cancer


`\begin{center}\vspace*{.25cm}`{=latex}

![](images/conclusion/deepmind.jpg){height=70%}

"Welcome to **DeepMind**: Embarking on **one of the greatest adventures**  \
in scientific history", available on YouTube since September 29, 2022.

`\end{center}\vspace*{-.3cm}`{=latex}



## 2020-2050: tough times ahead. Which problem are you going to solve?

`\begin{center}\vspace*{.5cm}`{=latex}

![](images/conclusion/problems.pdf){height=60%}

\
The French education system is giving you **genuine freedom** of choice. \
Use it **wisely**.


`\end{center}`{=latex}


## Find your own balance

`\begin{center}`{=latex}

![](images/conclusion/ikigai.pdf){height=95%}

`\end{center}`{=latex}



# References

